@@ -82,7 +82,7 @@ our $idle;    # idle handler
 our $main;    # main coro
 our $current; # current coro
 
-our $VERSION = 5.16;
+our $VERSION = 5.17;
 
 our @EXPORT = qw(async async_pool cede schedule terminate current unblock_sub);
 our %EXPORT_TAGS = (
@@ -209,14 +209,6 @@ Example: Create a new coro that just prints its arguments.
       print "@_\n";
    } 1,2,3,4;
 
-=cut
-
-sub async(&@) {
-   my $coro = new Coro @_;
-   $coro->ready;
-   $coro
-}
-
 =item async_pool { ... } [@args...]
 
 Similar to C<async>, but uses a coro pool, so you should not call
